package com.yovinchen.xlcs.acl.controller;

import com.yovinchen.xlcs.acl.service.PermissionService;
import com.yovinchen.xlcs.acl.service.RoleService;
import com.yovinchen.xlcs.common.result.Result;
import com.yovinchen.xlcs.model.acl.Permission;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * ClassName: PermissionController
 * Package: com.yovinchen.xlcs.acl.controller
 * 菜单服务
 *
 * @author yovinchen
 * @since 2023/9/14 14:03
 */
@RestController
@RequestMapping("/admin/acl/permission")
@Api(tags = "菜单服务")

public class PermissionController {

    @Autowired
    private PermissionService permissionService;

    @Autowired
    private RoleService roleService;
    @ApiOperation(value = "获取菜单")
    @GetMapping
    public Result index() {
        try {
            List<Permission> list = permissionService.queryAllMenu();
            return StringUtils.isNotEmpty(list.toString()) ? Result.ok(list) : Result.fail(list);
        } catch (Exception e) {
            throw new RuntimeException("获取菜单异常", e);
        }
    }

    @ApiOperation(value = "新增菜单")
    @PostMapping("save")
    public Result save(@RequestBody Permission permission) {
        try {
            boolean result = permissionService.save(permission);
            return result ? Result.ok(null) : Result.fail(null);
        } catch (Exception e) {
            throw new RuntimeException("新增菜单异常", e);
        }
    }

    @ApiOperation(value = "修改菜单")
    @PutMapping("update")
    public Result updateById(@RequestBody Permission permission) {
        try {
            boolean result = permissionService.updateById(permission);
            return result ? Result.ok(null) : Result.fail(null);
        } catch (Exception e) {
            throw new RuntimeException("修改菜单异常", e);
        }
    }

    @ApiOperation(value = "递归删除菜单")
    @DeleteMapping("remove/{id}")
    public Result remove(@PathVariable Long id) {
        try {
            boolean result = permissionService.removeChildById(id);
            return result ? Result.ok(null) : Result.fail(null);
        } catch (Exception e) {
            throw new RuntimeException("递归删除菜单异常", e);
        }
    }

    @ApiOperation(value = "根据角色获取菜单数据")
    @GetMapping("/toAssign/{roleId}")
    public Result toAssign(@PathVariable Long roleId) {
        Map<String, Object> roleMap = permissionService.findPermissionByRoleId(roleId);
        return Result.ok(roleMap);
    }

    @ApiOperation(value = "根据用户分配角色")
    @PostMapping("/doAssign")
    public Result doAssign(@RequestParam Long roleId, @RequestParam Long[] permissionId) {
        permissionService.saveRolePermissionRealtionShip(roleId, permissionId);
        return Result.ok(null);
    }
//    @ApiOperation(value = "获取一个角色的所有权限列表")
//    @GetMapping("toAssign/{id}")
//    public Result toAssign(@PathVariable Long id) {
//        try {
//            Map<String, Object> result = permissionService.getPermissionById(id);
//            return Result.ok(result);
//        } catch (Exception e) {
//            // 处理异常，例如记录日志或者抛出自定义异常
//            throw new RuntimeException("获取一个角色的所有权限列表异常", e);
//        }
//    }
}
