package com.yovinchen.xlcs.home.controller;

import com.yovinchen.xlcs.client.product.ProductFeignClient;
import com.yovinchen.xlcs.common.auth.AuthContextHolder;
import com.yovinchen.xlcs.common.result.Result;
import com.yovinchen.xlcs.home.service.HomeService;
import com.yovinchen.xlcs.home.service.ItemService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/**
 * ClassName: HomeApiController
 * Package: com.yovinchen.xlcs.home.controller
 *
 * @author yovinchen
 * @since 2023/9/25 12:10
 */

@Api(tags = "首页接口")
@RestController
@RequestMapping("api/home")
public class HomeApiController {
    @Autowired
    private ItemService itemService;
    @Resource
    private ProductFeignClient productFeignClient;
    @Autowired
    private HomeService homeService;

    @ApiOperation(value = "获取首页数据")
    @GetMapping("index")
    public Result index(HttpServletRequest request) {
        // 获取用户Id
        Long userId = AuthContextHolder.getUserId();
        Map<String, Object> map = homeService.homeData(userId);
        return Result.ok(map);
    }

    @ApiOperation(value = "获取分类信息")
    @GetMapping("category")
    public Result category() {
        return Result.ok(productFeignClient.findAllCategoryList());
    }

    @GetMapping("item/{id}")
    @ApiOperation("商品详情")
    public Result index(@PathVariable Long id) {
        Long userId = AuthContextHolder.getUserId();
        Map<String, Object> map = itemService.item(id, userId);
        return Result.ok(map);
    }

}
